@@ -18,7 +18,7 @@ class Store(S, ):
         self._initPrefs()
         self.getAccount().assure()
     def utcUnix(self):
-        return int(time.mktime(datetime.datetime.now(tz.utc).timetuple()))
+        return int(time.time())
     def getPref(self, name):
         assert (name in self._preferences)
         (typ, default) = self._preferences[name]
@@ -341,7 +341,13 @@ class Account(object, ):
         return self._row[name]
     def getId(self):
         return self.get('id')
+    def hasCustomCurrency(self):
+        if (self.get('currency_default') in config.get('currencies_order')):
+            return False
+        return True
     def getCurrencySymbol(self):
+        if self.hasCustomCurrency():
+            return self.get('currency_default')
         return config.getSymbolForCurrency(self.get('currency_default'))
     def getCurrency(self):
         return self.get('currency_default')
@@ -354,7 +360,7 @@ class Account(object, ):
     def getLastSync(self):
         ts = self.get('last_sync')
         if (ts > 0):
-            return datetime.datetime.fromtimestamp(ts).replace(tzinfo=tz.utc).astimezone(tz.local)
+            return datetime.datetime.fromtimestamp(ts)
         return None
     def getBareNumberFormat(self):
         return (self.get('format_number') % ('%s', '%s', ''))
